@@ -1,6 +1,7 @@
 from .api_client import NutanixApiClient, NutanixSession
 from .nutanix_cluster import ClusterMetadata, ClusterSpec, ClusterStatus, NutanixCluster
 from .nutanix_image import ImageMetadata, ImageSpec, ImageStatus, NutanixImage
+from .nutanix_task import NutanixTask, TaskStatus
 from .nutanix_vm import NutanixVM, NutanixVMLabel, PowerState, VMBootDevices, VMMetadata, VMSpec, VMStatus
 
 __all__ = [
@@ -23,4 +24,6 @@ __all__ = [
     "exceptions",
     "NutanixVMLabel",
     "VMBootDevices",
+    "NutanixTask",
+    "TaskStatus",
 ]
